@@ -302,8 +302,18 @@ class Abba:
                 Abba.opened_atlases[atlas_name] = atlas
             else:
                 bg_atlas = BrainGlobeAtlas(atlas_name)
-                from src.abba_python.abba_private.AbbaAtlas import \
-                    AbbaAtlas  # delayed import because the jvm should be correctly
+
+                try:
+                    from abba_python.abba_private.AbbaAtlas import \
+                        AbbaAtlas  # delayed import because the jvm should be set first
+                except:
+                    try:
+                        from .abba_private.AbbaAtlas import \
+                            AbbaAtlas  # delayed import because the jvm should be set first
+                    except:
+                        print(
+                            "Could not import DeepSliceProcessor because the dev do not understand python modules and submodules.")
+
                 # initialized
                 atlas = AbbaAtlas(bg_atlas, ij)
                 atlas.initialize(None, None)
